package cn.com.infosec.asn1;

import java.math.BigInteger;

public class DERInteger extends ASN1Object {
   byte[] bytes;

   public static DERInteger getInstance(Object obj) {
      if (obj != null && !(obj instanceof DERInteger)) {
         if (obj instanceof ASN1OctetString) {
            return new DERInteger(((ASN1OctetString)obj).getOctets());
         } else if (obj instanceof ASN1TaggedObject) {
            return getInstance(((ASN1TaggedObject)obj).getObject());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (DERInteger)obj;
      }
   }

   public static DERInteger getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   public DERInteger(int value) {
      this.bytes = BigInteger.valueOf((long)value).toByteArray();
   }

   public DERInteger(BigInteger value) {
      this.bytes = value.toByteArray();
   }

   public DERInteger(byte[] bytes) {
      this.bytes = bytes;
   }

   public BigInteger getValue() {
      return new BigInteger(this.bytes);
   }

   public BigInteger getPositiveValue() {
      return new BigInteger(1, this.bytes);
   }

   void encode(DEROutputStream out) {
      out.writeEncoded(2, this.bytes);
   }

   public int hashCode() {
      int var1 = 0;

      byte[] var3;
      for(int var2 = 0; var2 != (var3 = this.bytes).length; ++var2) {
         var1 ^= (var3[var2] & 255) << var2 % 4;
      }

      return var1;
   }

   boolean asn1Equals(DERObject o) {
      if (!(o instanceof DERInteger)) {
         return false;
      } else {
         DERInteger o1 = (DERInteger)o;
         if (this.bytes.length != o1.bytes.length) {
            return false;
         } else {
            byte[] var3;
            for(int var2 = 0; var2 != (var3 = this.bytes).length; ++var2) {
               if (var3[var2] != o1.bytes[var2]) {
                  return false;
               }
            }

            return true;
         }
      }
   }

   public String toString() {
      return this.getValue().toString();
   }
}
